wiki.languages.en = {
  "__code" : "en",
  "__description" : "English",
  "arrow_left_alt" : "Left arrow icon",
  "arrow_right_alt" : "Right arrow icon",
  "change_language" : "Change language",
  "close": "Close",
  "close_modal": "Close modal",
  "cookies_message" : "This wiki is not using cookies.",
  "contents" : "Contents",
  "docs_topics_title" : "Topics",
  "last_update" : "Last update",
  "left_arrow_icon" : "Left arrow icon",
  "menu_icon_alt" : "Navigation icon",
  "months" : {
    "01" : "January",
    "02" : "February",
    "03" : "March",
    "04" : "April",
    "05" : "May",
    "06" : "June",
    "07" : "July",
    "08" : "August",
    "09" : "September",
    "10" : "October",
    "11" : "November",
    "12" : "December"
  },
  "navigation_icon" : "Navigation icon",
  "next" : "Next",
  "on_this_page" : "On this page",
  "organisation_logo" : "Organisation logo",
  "page404_message" : "I'm sorry, but I can't find the page you are looking for. It looks like the link you followed doesn’t lead anywhere. The page may have been moved, renamed… or maybe it never existed!<br><br>Try browsing the navigation menu or use the search tool to find what you're looking for.",
  "page404_title" : "404",
  "page_contents_title" : "Contents",
  "pdf_version" : "Pdf version",
  "previous" : "Previous",
  "right_arrow_icon" : "Right arrow icon",
  "search": "Search",
  "search_icon" : "Search icon",
  "search_page_input" : "Find in documentation",
  "search_page_no_results" : "I am sorry, but I am not able to find what you are looking for.",
  "search_placeholder" : "Search...",
  "search_results" : "Search results",
  "search_within_the_wiki" : "Search within the wiki",
  "select_language" : "Select language",
  "support" : "Support",
  "topics" : "Topics",
  "use_keywords" : "Use keywords...",
  "useful_links" : "Useful links"
};